@@ -251,7 +251,8 @@ bootstrap_bundle <- function(version) {
       sass_layer(
         functions = bs5_sass_files("functions"),
         defaults = bs5_sass_files("variables"),
-        mixins = bs5_sass_files("mixins")
+        mixins = list(bs5_sass_files("maps"), bs5_sass_files("mixins")),
+        rules = list(bs5_sass_files("mixins/banner"), "@include bsBanner('')")
       ),
       # Returns a _named_ list of bundles (i.e., these should be easily removed)
       !!!rule_bundles(
@@ -268,7 +269,12 @@ bootstrap_bundle <- function(version) {
       ),
       # Additions to BS5 that are always included (i.e., not a part of compatibility)
       sass_layer(rules = pandoc_tables),
-      bs3compat = bs3compat_bundle()
+      bs3compat = bs3compat_bundle(),
+      !!!rule_bundles(c(
+        system_file("components", "card.scss", package = "bslib"),
+        system_file("components", "value_box.scss", package = "bslib"),
+        system_file("components", "layout_column_wrap.scss", package = "bslib")
+      ))
     ),
     four = sass_bundle(
       sass_layer(
