@@ -7,7 +7,8 @@ pkgload::load_all()
 lapply(c(
   "yarn_install.R",
   "download_bootswatch_fonts.R",
-  "update_gfont_info.R"
+  "update_gfont_info.R",
+  "expand_variables_article_template.R"
 ), function(file) {
   message("Updating: ", file)
   source(file.path("tools", file), local = TRUE)
